@@ -19,11 +19,11 @@ CPAN::UnsupportedFinder analyzes CPAN modules for test results and maintenance s
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -47,13 +47,21 @@ Creates a new instance. Accepts the following arguments:
 
 =over 4
 
-=item verbose
+=item * verbose
 
 Enable verbose output.
 
+=item * api_url
+
+metacpan URL, defaults to L<https://fastapi.metacpan.org/v1>
+
+=item * cpan_testers
+
+CPAN testers URL, detaults to L<https://api.cpantesters.org/api/v1>
+
 =back
 
-=cut 
+=cut
 
 sub new {
 	my $class = shift;
@@ -83,9 +91,10 @@ sub new {
 	}
 
 	my $self = {
-		api_url	=> 'https://fastapi.metacpan.org/v1',
+		api_url => 'https://fastapi.metacpan.org/v1',
 		cpan_testers => 'https://api.cpantesters.org/api/v1',
-		verbose	=> $args{verbose} || 0,
+		verbose => 0,
+		%args
 	};
 
 	Log::Log4perl->easy_init($self->{verbose} ? $Log::Log4perl::DEBUG : $Log::Log4perl::ERROR);
@@ -109,7 +118,7 @@ sub analyze {
 	for my $module (@modules) {
 		$self->{logger}->debug('Analyzing module');
 
-		my $test_data	= $self->_fetch_testers_data($module);
+		my $test_data = $self->_fetch_testers_data($module);
 		my $release_data = $self->_fetch_release_data($module);
 
 		my $unsupported = $self->_evaluate_support($module, $test_data, $release_data);
@@ -205,7 +214,7 @@ sub _evaluate_support {
 
 	if($failure_rate > 0.5 || !$last_update || $last_update lt '2022-01-01') {
 		return {
-			module	=> $module,
+			module => $module,
 			failure_rate => $failure_rate,
 			last_update => $last_update || 'Unknown',
 			reverse_deps => $reverse_deps->{total} || 0,
@@ -220,7 +229,7 @@ sub _calculate_failure_rate {
 	return 0 unless $test_data && $test_data->{results};
 
 	my $total_tests = $test_data->{results}{total};
-	my $failures	= $test_data->{results}{fail};
+	my $failures = $test_data->{results}{fail};
 
 	return $total_tests ? $failures / $total_tests : 1;
 }
